package com.skyarts.android.universalchardetecttest;

import java.io.UnsupportedEncodingException;

import com.skyarts.android.universalchardetect.IUniversalCharDetectService;
import com.skyarts.android.universalchardetecttest.R;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ComponentName;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class MainActivity extends Activity {
    private static final String APP_TAG = "UniversalCharDetectServiceTest";

    /** ICharDetectService */
    private IUniversalCharDetectService iUCDService;

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);


        // bind IUniversalCharDetectService
        Intent intent = new Intent(IUniversalCharDetectService.class.getName());
        bindService(intent, iUCDServiceConnection, BIND_AUTO_CREATE);


        Button button = (Button)findViewById(R.id.Button01);
        button.setOnClickListener(new OnClickListener() {
            public void onClick(View v) {
                //Char test
                try {
//                    byte[] baseBytes = "\u3042".getBytes("UTF-8");//Japanese Hiragana Letter A & I
                    byte[] baseBytes = "\u3042".getBytes("UTF-16");//Japanese Hiragana Letter A & I

                    //Call IUniversalCharDetectService
                    String encoding = iUCDService.getDetectedCharset(baseBytes, 0, baseBytes.length);
                    String messageText;
                    if(encoding != null) {
                        messageText = "Detected encoding: " + encoding;
                    }else {
                        messageText = "No encoding detected.";
                    }
                    //Result
                    AlertDialog errDialog = new AlertDialog.Builder(MainActivity.this)
                    .setTitle(APP_TAG)
                    .setMessage(messageText)
                    .setPositiveButton("OK", new DialogInterface.OnClickListener() {
                        public void onClick(DialogInterface dialog, int whichButton) {
                        }
                    })
                    .setIcon(android.R.drawable.ic_dialog_alert)
                    .create();
                    errDialog.setCancelable(true);
                    errDialog.show();

                }catch(RemoteException ex) {
                    Log.e(APP_TAG, ex.toString());
                } catch (UnsupportedEncodingException e) {
                    Log.e(APP_TAG, e.toString());
                }
            }
        });
    }

    /* (non-Javadoc)
     * @see android.app.Activity#onDestroy()
     */
    @Override
    protected void onDestroy() {
        super.onDestroy();

        //***** Don't forget!! *****//
        //un-bind IUniversalCharDetectService
        unbindService(iUCDServiceConnection);
    }


    private ServiceConnection iUCDServiceConnection = new ServiceConnection() {
        public void onServiceConnected(ComponentName name, IBinder service) {
            iUCDService = IUniversalCharDetectService.Stub.asInterface(service);
        }

        public void onServiceDisconnected(ComponentName name) {
            iUCDService = null;
        }
    };

}